@@ -1,11 +1,11 @@
 use strict;
 use warnings;
-package Dist::Zilla::Role::RepoFileInjector; # git description: v0.001-3-g0498cda
+package Dist::Zilla::Role::RepoFileInjector; # git description: v0.002-2-ge01da61
 # ABSTRACT: Create files outside the build directory
 # KEYWORDS: plugin distribution generate create file repository
 # vim: set ts=8 sts=4 sw=4 tw=115 et :
 
-our $VERSION = '0.002';
+our $VERSION = '0.003';
 
 use Moose::Role;
 
@@ -19,7 +19,7 @@ has repo_root => (
     is => 'ro', isa => Str,
     predicate => '_has_repo_root',
     lazy => 1,
-    default => sub { Cwd::getcwd() },
+    default => sub { path(Cwd::getcwd())->stringify },
 );
 
 has allow_overwrite => (
@@ -104,7 +104,7 @@ Dist::Zilla::Role::RepoFileInjector - Create files outside the build directory
 
 =head1 VERSION
 
-version 0.002
+version 0.003
 
 =head1 SYNOPSIS
 
